aboutsummaryrefslogtreecommitdiff
path: root/bank3.s
diff options
context:
space:
mode:
authorB. Watson <yalhcru@gmail.com>2021-04-16 12:34:12 -0400
committerB. Watson <yalhcru@gmail.com>2021-04-16 12:34:12 -0400
commitf822c52838af6884792f3a1f16aad29f5174a913 (patch)
tree98beb304fe1787423fdb7a7efdd7cc0edda69e1c /bank3.s
parentd3d67168c37bf0d95477c8eb58b6dc24f7e815ad (diff)
downloadtaipan-f822c52838af6884792f3a1f16aad29f5174a913.tar.gz
Use full 8K banks for cartridge build
Diffstat (limited to 'bank3.s')
-rw-r--r--bank3.s14
1 files changed, 7 insertions, 7 deletions
diff --git a/bank3.s b/bank3.s
index 2f7733c..9a1fce1 100644
--- a/bank3.s
+++ b/bank3.s
@@ -38,9 +38,9 @@ mem_msg:
scrcode "Need at least 32K"
mem_msg_len = * - mem_msg - 1
; copy_31_pages:
; copy 7936 bytes from $8000-$9dff to (destptr).
; on exit, destptr points to the next 7936 byte chunk.
; copy_x_pages:
; as above, but accepts number of pages to copy in X register.
@@ -49,8 +49,8 @@ mem_msg_len = * - mem_msg - 1
; as copy_x_pages, but the caller must set up srcptr as well
; as the X reg.
-copy_31_pages:
- ldx #$1f
+copy_32_pages:
+ ldx #$20
copy_x_pages:
lda #$0
sta srcptr
@@ -113,11 +113,11 @@ mem_ok:
; I can shrink the code down to fit in 0 and 1 only.
lda #0 ; bank 0...
sta CCNTL ; ...select it
- jsr copy_31_pages
+ jsr copy_32_pages
lda #1 ; bank 1...
sta CCNTL ; ...select it
- jsr copy_31_pages
+ jsr copy_32_pages
; tail end of the code is stored in this bank.
lda #<code_tail
@@ -38,9 +38,9 @@ mem_msg:
scrcode "Need at least 32K"
mem_msg_len = * - mem_msg - 1
-; copy_31_pages:
-; copy 7936 bytes from $8000-$9dff to (destptr).
-; on exit, destptr points to the next 7936 byte chunk.
+; copy_32_pages:
+; copy 8192 bytes from $8000-$9fff to (destptr).
+; on exit, destptr points to the next 8192 byte chunk.
; copy_x_pages:
; as above, but accepts number of pages to copy in X register.